Crate rieltor_parser

Crate rieltor_parser 

Modules

apartment
Module containing types for parsing apartments.

Structs

ApartmentParser
Parser struct for handling the grammar defined in grammar.pest.

Enums

Rule

Functions

fetch_apartment_html_from_url
Fetches the HTML content of a single apartment page from the given URL.
fetch_apartment_list_html_from_url
Fetches the HTML content of an apartment list page from the given URL.
load_html
Loads the content of an HTML file from the specified path.
parse
Parses the HTML content of a single apartment page into an Apartment struct.
parse_apartment
Parses a single apartment from the specified source.
parse_apartment_list
Parses a list of apartments from the specified source.
save_apartments_to_directory
Fetches and parses apartment details from a URL or file.
save_to_json
Saves an apartment to a JSON file.