load_html

Function load_html 

pub fn load_html(file_path: &str) -> Result<String>
Loads the content of an HTML file from the specified path.

Arguments

  • file_path - Path to the HTML file.

Returns

A Result containing the content of the file as a String, or an error if the file cannot be read.