Modules
- apartment
- Module containing types for parsing apartments.
Structs
- Apartment
Parser - Parser struct for handling the grammar defined in
grammar.pest.
Enums
Functions
- fetch_
apartment_ html_ from_ url - Fetches the HTML content of a single apartment page from the given URL.
- fetch_
apartment_ list_ html_ from_ url - Fetches the HTML content of an apartment list page from the given URL.
- load_
html - Loads the content of an HTML file from the specified path.
- parse
- Parses the HTML content of a single apartment page into an
Apartmentstruct. - parse_
apartment - Parses a single apartment from the specified source.
- parse_
apartment_ list - Parses a list of apartments from the specified source.
- save_
apartments_ to_ directory - Fetches and parses apartment details from a URL or file.
- save_
to_ json - Saves an apartment to a JSON file.